<?php
// $Id: classes_and_lessons.inc,v 1.1 2009/08/23 10:28:58 tutumlum Exp $

/**
 * @file
 * Helper functions for the clases_and_lessons module.
 */

/**
 * Form to delete a recorded class
 *
 * @param $class
 *   name of class which will be deleted
 * @return
 *   form array
 */
function classes_and_lessons_delete_class_form($class) {
  $form['class_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Class Name'),
    '#weight' => 1,
    '#required' => TRUE,
    '#default_value' => isset($class) ? $class : '',
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Delete'),
    '#weight' => 10,
  );
  return $form;
}

function classes_and_lessons_delete_student_class_form() {
  $path_arr = explode('/', current_path());
  $school_no = array_pop($path_arr);
  $class = array_pop($path_arr);
  $text = t("You are about to delete !student from !class ", array('!student' => $school_no, '!class' => $class));
  $form['delete'] = array(
    '#type' => 'value',
    '#value' => 1,
  );
  $form['submit'] = array(
    '#prefix' => $text,
    '#id' => 1,
    '#type' => 'submit',
    '#value' => t('Delete'),
    '#weight' => 10,
  );
  return $form;
}

function classes_and_lessons_student_class_form() {
  $form['class_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Class Name'),
    '#weight' => 1,
    '#required' => TRUE,
    '#default_value' => isset($class) ? $class : '',
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
    '#weight' => 10,
  );
  return $form;
}

function classes_and_lessons_add_student_class_form() {
  $form['class_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Class Name'),
    '#weight' => 1,
    '#required' => TRUE,
    '#size' => 20,
    '#default_value' => isset($class) ? $class : '',
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Add New'),
    '#weight' => 10,
  );
  return $form;
}

/**
 * Get list of classes with any student registered.
 *
 * @return
 *   linear array of classes
 */
function classes_and_lessons_listof_all_classes() {
  return db_query("
    SELECT DISTINCT class 
    FROM {classes_and_lessons_student_classes} 
    WHERE academic_year = :cyear",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR)
  )
  ->fetchCol();
}

/**
 * Get list of currently teaching teachers with weekly teaching hours.
 *
 * @return
 *   associative array of teacher user id's and weekly teaching hours
 */
function classes_and_lessons_tcl_teachers() {
  return db_query("
    SELECT teacher, SUM(lesson_hour) 
    FROM {classes_and_lessons_tcl} 
    WHERE academic_year = :cyear 
    GROUP BY teacher 
    ORDER BY 1", 
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR)
  )
  ->fetchAllKeyed();
}

/**
 * Get list of classes with weekly teaching hours.
 *
 * @return
 *   associative array of classes and weekly teaching hours
 */
function classes_and_lessons_tcl_classes() {
  return db_query("
    SELECT class, SUM(lesson_hour) 
    FROM {classes_and_lessons_tcl} 
    WHERE academic_year = :cyear 
    GROUP BY teacher 
    ORDER BY 1",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR)
  )
  ->fetchAllKeyed();
}

/**
 * Get list of lessons with weekly teaching hours.
 *
 * @return
 *   associative array of lessons and weekly teaching hours
 */
function classes_and_lessons_tcl_lessons() {
  return db_query("
    SELECT lesson, SUM(lesson_hour) 
    FROM {classes_and_lessons_tcl} 
    WHERE academic_year = :cyear 
    GROUP BY teacher 
    ORDER BY 1",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR)
  )
  ->fetchAllKeyed();
}


/**
 * Form to add lessons / edit lesson names.
 *
 * @return
 *   rendered form
 */
function classes_and_lessons_form_lessons($form_state) {
  $form['lessons'] = array(
    '#type' => 'textarea',
    '#title' => t('Lessons'),
    '#size' => 1,
    '#default_value' => variable_get('classes_and_lessons_lessons'),
    '#description' => t("Add available lesson name as a lesson per line<br/>"),
  );
  return system_settings_form($form);
}

/**
 * Populate class-lesson-teacher triad information for any triad members.
 *
 * @param $op
 *   name of one of tcl triad member
 * @param $value
 *   name of triad member
 * @return
 *   id associated 2-dimentional array of selected tcl triads
 */
function classes_and_lessons_tcl_details($op, $value) {
  switch ($op) {
    case 'teacher' :
      return db_query("SELECT id, class AS value1, lesson AS value2, lesson_hour 
        FROM {classes_and_lessons_tcl} 
        WHERE teacher = :val
        AND academic_year = :cyear",
        array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':val' => $value)
      )
      ->fetchAllAssoc('id');
    
    case 'class' :
      return db_query("
        SELECT id, lesson AS value1, teacher AS value2, lesson_hour 
        FROM {classes_and_lessons_tcl} 
        WHERE class = :val
        AND academic_year = :cyear",
        array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':val' => $value)
      )
      ->fetchAllAssoc('id');
    
    case 'lesson' :
      return db_query("
        SELECT id, class AS value1, teacher AS value2, lesson_hour 
        FROM {classes_and_lessons_tcl} 
        WHERE lesson = :val
        AND academic_year = :cyear",
        array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':val' => $value)
      )
      ->fetchAllAssoc('id');
  }
}

/**
 * tcl info by id
 *
 * @param $tcl
 *   teacher-class-lesson triad id
 * @return
 *   stdClass Object for tcl triad row
 */
function classes_and_lessons_tcl_by_id($tcl) {
  return db_query("
    SELECT * 
    FROM {classes_and_lessons_tcl} 
    WHERE id = :id 
    AND academic_year = :cyear",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':id' => $tcl)
  )
  ->fetch();
}

/**
 * Get list of classes which a student belong to.
 *
 * @param $school_no
 *   uid of student
 * @return
 *   linear array of classes
 */
function classes_and_lessons_listof_student_classes($school_no) {
  return db_query("
    SELECT class 
    FROM {classes_and_lessons_student_classes} 
    WHERE school_no = :no 
    AND academic_year = :cyear",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':no' => $school_no)
  )
  ->fetchCol();
}

/**
 * Get list of students registered to given class.
 *
 * @param $class
 *   suggested class
 * @return
 *   linear array of students' uid's
 */
function classes_and_lessons_class_list($class) {
  return db_query("
    SELECT cl.school_no 
    FROM {classes_and_lessons_student_classes} cl
    WHERE NOT EXISTS 
    (SELECT * 
      FROM {school_administration_withdrawal} wt
      WHERE cl.school_no = wt.school_no
      AND academic_year = :cyear
    )
    AND class = :class",
    array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':class' => $class)
  )
  ->fetchCol();
  $students;
}

/**
 * Check user is homeroom teacher or not.
 *
 * @param $uid
 *   uid of user
 * @return
 *   if user is homeroom teacher of any class returns array of classes else returns FALSE
 */
function classes_and_lessons_hr_teacher($uid) {
  $result = db_query("
    SELECT class
    FROM {classes_and_lessons_class_info} 
    WHERE (hr_teacher1 = :uid1 OR hr_teacher2 = :uid2)
    AND academic_year = :cyear", array(
      ':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, 
      ':uid1' => $uid, 
      ':uid2' => $uid,
    )
  )
  ->fetchCol();
  return ($result) ? $result : FALSE;
}

/**
 * Check user is supervisor of any class or not.
 *
 * @param $uid
 *   uid of user
 * @return
 *   if user is supervisor of any class returns array of classes else returns FALSE
 */
function classes_and_lessons_supervisor($uid) {
  $result = db_query("
    SELECT class
    FROM {classes_and_lessons_class_info} 
    WHERE (supervisor1 = :uid1 OR supervisor2 = :uid2 OR supervisor3 = :uid3)
    AND academic_year = :cyear", array(
      ':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, 
      ':uid1' => $uid,
      ':uid2' => $uid,
      ':uid3' => $uid,
    )
  )
  ->fetchColl();
  return ($result) ? $result : FALSE;
}

/**
 * Check user is teaching to any class or not.
 *
 * @param $uid
 *   uid of user
 * @return
 *   if user is teaching to any class returns array of classes else returns FALSE
 */
function classes_and_lessons_teaching($uid) {
  $result = db_query("
    SELECT id, class 
    FROM {classes_and_lessons_tcl}
    WHERE staff_no = :uid",
    array(':uid' => $uid)
  )
  ->fetchAllKeyed();
  return ($result) ? $result : FALSE;
}


/**
 * Get whole information of a class or classes.
 *
 * @param $class
 *   class name or NULL for all classes
 * @return
 *   associative array of classes info keyed by class name
 */
function classes_and_lessons_class_load($class = NULL) {
  if ($class == NULL) {
    $result = db_query("
      SELECT *
      FROM {classes_and_lessons_class_info}
      WHERE academic_year = :cyear",
      array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR)
    )
    ->fetchAllAssoc('name');
    return $result;
  }
  else {
    $result = db_query("
      SELECT *
      FROM {classes_and_lessons_class_info}
      WHERE name = :name
      AND academic_year = :cyear",
      array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':name' => $class)
    )
    ->fetch();
    $result->teachers = db_query("
      SELECT lesson, teacher
      FROM {classes_and_lessons_tcl}
      WHERE class = :class
      AND academic_year = :cyear",
      array(':cyear' => SCHOOL_ADMINISTRATION_C_YEAR, ':class' => $class)
    )
    ->fetchAllKeyed();
    return $result;
  }
}

/**
 * Delete class form validation function.
 */
function classes_and_lessons_delete_class_form_validate($form_id, &$form_state) {
  $result = db_query("
    SELECT COUNT(*) 
    FROM {classes_and_lessons_class_info}
    WHERE name = :class",
    array(':class', $form_state['values']['class_name'])
  )
  ->fetchField();
  if ($result == 0) {
    form_set_error('class_name', t("There is no class named !class recorded..", array('!class' => $form_state['values']['class_name'])));
  }
}

/**
 * Delete class form submit.
 */
function classes_and_lessons_delete_class_form_submit($form_id, &$form_state) {
  db_delete('classes_and_lessons_class_info')
  ->condition('name', $form_state['values']['class_name'], '=')
  ->execute();
  drupal_set_message(
    t('!class is deleted..', array('!class' => $form_state['values']['class_name']))
  );
}

/**
 * tcl edit form submit.
 */
function classes_and_lessons_tcl_edit_form_submit($form_id, &$form_state) {
  $fields = array('class' => $form_state['values']['class_name'],
    'lesson_hour' => $form_state['values']['lesson_hour'],
    'lesson'      => $form_state['values']['lesson'],
    'teacher'     => $form_state['values']['teacher'],
  );
  if (isset($form_state['values']['tclid'])) {
    if ($form_state['clicked_button']['#parents'][0] == 'delete') {
      db_delete('classes_and_lessons_tcl')
      ->condition('id', $form_state['values']['tclid'], '=')
      ->execute();
      drupal_set_message(
        t('Teacher-Class-Lesson match with id = !id is deleted..', 
          array('!id' => $form_state['values']['tclid'])
        )
      );
      $path_arr = explode('/', current_path());
      array_pop($path_arr);
      $form = drupal_retrieve_form('classes_and_lessons_tcl_edit_form', $form_state);
      drupal_redirect_form($form, implode('/', $path_arr));
    }
    else {
      db_update('classes_and_lessons_tcl')
      ->fields($fields)
      ->condition('id', $form_state['values']['tclid'], '=')
      ->execute();
      drupal_set_message(t('Teacher-Class-Lesson match is updated..'));
    }
  }
  else {
    db_insert('classes_and_lessons_tcl')
    ->fields($fields)
    ->execute();
    drupal_set_message(t('New Teacher-Class-Lesson matching is saved..'));
  }
}