<?php
// $Id: school_administration.forms.inc,v 1.1 2009/08/23 10:28:19 tutumlum Exp $

/**
 * @file
 * form build functions for the school_administration module.
 *
 * Copyright 2009 by Murat Tutumlu ("tutumlum", http://drupal.org/user/413570)
 */

function school_administration_student_registration_form($form_state) {
  $form[] = school_administration_identity_information();
  $form[] = school_administration_contact_info_form();
  foreach (explode(chr(10), trim(variable_get('school_administration_num_range'))) as $val) {
    $r = explode('=>', $val);
    $ranges[] = trim($r[0]);
  }
  $form['student'] = array(
    '#type' => 'fieldset',
    '#weight' => -1,
    '#title' => t('Study Information'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  if (variable_get('st_id_conf', 'default') != 'default') {
    $form['student']['num_range'] = array(
      '#type' => 'select',
      '#weight' => 0,
      '#title' => t('School No Range'),
      '#required' => TRUE,
      '#options' => $ranges,
    );
  }
  $form['student']['Level'] = array(
    '#type' => 'textfield',
    '#weight' => 1,
    '#title' => t('Level'),
    '#size' => 20,
    '#required' => TRUE,
    '#description' => t('Should be an integer'),
  );
  $form['student']['EnrollmentDate'] = array(
    '#type' => 'date',
    '#weight' => 2,
    '#title' => t('Enrollment Date'),
    '#required' => TRUE,
    '#default_value' => array('day' => date("j"), 'month' => date("n"), 'year' => date("Y")),
  );
  $form['student']['EntranceR'] = array(
    '#type' => 'textfield',
    '#weight' => 3,
    '#size' => 20,
    '#title' => t('Entrance Exam Result'),
  );
  $form['student']['St_Resides'] = array(
    '#type' => 'radios',
    '#title' => t('Student resides with'),
    '#weight' => 4,
    '#required' => TRUE,
    '#key_type' => 'associative',
    '#options' => variable_get('school_administration_resides_with'),
  );
  $form['scholarship'] = array(
    '#type' => 'fieldset',
    '#weight' => 2,
    '#title' => t('Scholarship Information'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['scholarship']['Scholarship'] = array(
    '#type' => 'radios',
    '#title' => t('Scholarship'),
    '#weight' => 5,
    '#key_type' => 'associative',
    '#default' => 0,
    '#options' => array(
      1 => t('Yes'),
      0 => t('No'),
    ),
  );
  $form['scholarship']['SchsDesc'] = array(
    '#type' => 'textarea',
    '#weight' => 6,
    '#resizable' => FALSE,
    '#cols' => 88,
    '#rows' => 2,
    '#title' => t('Scholarship Description'),
  );
  $form['Sibling'] = array(
    '#type' => 'textfield',
    '#weight' => 3,
    '#size' => 20,
    '#title' => t('Sibling School No'),
  );
  $form['submit'] = array(
    '#weight' => 30,
    '#type' => 'submit',
    '#value' => t('Register'),
  );
  return $form;
}

function school_administration_staff_registration_form($form_state) {
  $form[] = school_administration_identity_information();
  $form[] = school_administration_contact_info_form();
  $form['staff'] = array(
    '#type' => 'fieldset',
    '#weight' => 0,
    '#title' => t('Staff Information'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
    $form['staff']['StartDate'] = array(
    '#type' => 'date',
    '#weight' => 0,
    '#required' => TRUE,
    '#default_value' => array('day' => date("j"), 'month' => date("n"), 'year' => date("Y")),
    '#title' => t('Start Date'),
  );
  $form['staff']['Job'] = array(
    '#type' => 'select',
    '#required' => TRUE,
    '#weight' => 2,
    '#title' => t('Job'),
    '#options' => drupal_map_assoc(explode("\n", variable_get('school_administration_jobs'))),
  );
  $form['staff']['Branch'] = array(
    '#type' => 'textfield',
    '#size' => 20,
    '#weight' => 3,
    '#title' => t('Branch'),
  );
  $form['staff']['Contract'] = array(
    '#type' => 'textfield',
    '#size' => 20,
    '#weight' => 5,
    '#title' => t('Contract Type'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#weight' => 1,
    '#value' => t('Register'),
  );
  return $form;
}

function school_administration_parent_registration_form($form_state, $path) {
  $form[] = school_administration_identity_information();
  $form[] = school_administration_work_info_form();
  $form[] = school_administration_contact_info_form();
  $path_arr = explode('/', $path);
  if(count($path_arr) == 2) {
    $school_no = $path_arr[0];
    $resides = $path_arr[1];
  }
  else {
    $school_no = NULL;
    $resides = NULL;
  }
  $form['parent'] = array(
    '#type' => 'fieldset',
    '#weight' => -1,
    '#title' => t('Parenting Information'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['parent']['School_No'] = array(
    '#type' => 'textfield',
    '#title' => t('School No of Student'),
    '#default_value' => $school_no,
    '#weight' => 1,
    '#required' => TRUE,
    '#size' => 20,
  );
  $form['parent']['Relation'] = array(
    '#type' => 'select',
    '#title' => t('Relationship'),
    '#weight' => 2,
    '#required' => TRUE,
    '#options' => drupal_map_assoc(explode("\n", variable_get('school_administration_relations'))),
  );
  $form['parent']['Guardian'] = array(
    '#type' => 'checkbox',
    '#title' => t('Guardian'),
    '#weight' => 3,
  );
  $form['parent']['Resides'] = array(
    '#type' => 'value',
    '#value' => $resides,
    '#title' => t('Guardian'),
    '#weight' => 3,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#weight' => 30,
    '#value' => t('Register'),
  );
  return $form;
}

function school_administration_student_withdraw_form($form_state) {
  $form['School_No'] = array(
    '#type' => 'textfield',
    '#weight' => 1,
    '#title' => t('School No'),
    '#required' => TRUE,
    '#description' => t('Multiple records are available by separating - (dash). e.g. 2122-2123'),
  );
  $form['withdraw'] = array(
    '#type' => 'fieldset',
    '#weight' => 2,
    '#title' => t('Withdrawal Information'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['withdraw']['date'] = array(
    '#type' => 'date',
    '#weight' => 2,
    '#required' => TRUE,
    '#default_value' => array('day' => date("j"), 'month' => date("n"), 'year' => date("Y")),
    '#title' => t('Withdrawal Date'),
  );
  $form['withdraw']['reason'] = array(
    '#type' => 'select',
    '#title' => t('Withdraw Reason'),
    '#weight' => 3,
    '#required' => TRUE,
    '#options' => drupal_map_assoc(explode("\n", variable_get('school_administration_withd'))),
  );
  $form['withdraw']['doc'] = array(
    '#type' => 'textfield',
    '#title' => t('Given Documents In Withdrawal'),
    '#weight' => 4,
  );
  $form['withdraw']['dept_left'] = array(
    '#type' => 'textfield',
    '#title' => t('Debt Of Student Left'),
    '#weight' => 5,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['withdraw']['status'] = array(
    '#type' => 'checkbox',
    '#title' => t('No documentation will be given in future'),
    '#weight' => 6,
  );
  $form['withdraw']['notes'] = array(
    '#type' => 'textarea',
    '#title' => t('Notes'),
    '#weight' => 7,
    '#resizable' => FALSE,
    '#cols' => 58,
  );
  $form['submit'] = array(
    '#weight' => 8,
    '#type' => 'submit',
    '#value' => t('Insert Record'),
  );
  return $form;
}

function school_administration_staff_withdraw_form($form_state) {
  $form['staff_no'] = array(
    '#type' => 'textfield',
    '#weight' => 1,
    '#title' => t('Staff No'),
    '#required' => TRUE,
    '#size' => 22,
  );
  $form['date'] = array(
    '#type' => 'date',
    '#weight' => 2,
    '#required' => TRUE,
    '#default_value' => array('day' => date("j"), 'month' => date("n"), 'year' => date("Y")),
    '#title' => t('Withdrawal Date'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#weight' => 8,
    '#value' => t('Insert Record'),
  );
  return $form;
}

function school_administration_insert_portrait_form($form_state) {
  $form['pdir'] = array(
    '#type' => 'textfield',
    '#weight' => 0,
    '#title' => t('Portrait Photos Directory'),
    '#default_value' => 'portraits',
    '#description' => t('folder name in Drupal installation directory'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#id' => 'add-portrait',
    '#value' => t('Insert Photos'),
    '#weight' => 1,
  );
  return $form;
}

function school_administration_admin($form_state) {
  $form['school_administration_s_year'] = array(
    '#type' => 'textfield',
    '#title' => t('Starting Year'),
    '#default_value' => variable_get('school_administration_s_year', 2000),
    '#size' => 4,
    '#maxlength' => 4,
    '#description' => t('Starting education year of school history in database')
  );
  $form['school_administration_c_year'] = array(
    '#type' => 'textfield',
    '#title' => t('Current Academic Year of the system'),
    '#default_value' => SCHOOL_ADMINISTRATION_C_YEAR,
    '#size' => 4,
    '#maxlength' => 4,
    '#description' => t('If academic year is 2000-2001, type 2001<br/>'
      . 'Default value is <b>' 
      . date("Y") 
      . '</b> before September 1, <b>' 
      . (date("Y") + 1) 
      . '</b> after August 30.'),
  );
  $form['school_administration_full_name_format'] = array(
    '#type' => 'radios',
    '#title' => t('Full Name Format'),
    '#key_type' => 'associative',
    '#default_value' => 0,
    '#options' => array(
      'Name1 Name2 Name3 Surname',
      'Title Name1 Name2 Name3 Middle_Name Surname',
      'SURNAME, Name1 Name2 Name3',
    ),
    '#description' => t("Choose Name Format to use globally"),
  );
  $form['School_No'] = array(
    '#type' => 'fieldset',
    '#title' => t("Enrolling Student's ID"),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['School_No']['school_administration_st_id_conf'] = array(
    '#type' => 'radios',
    '#title' => t('Student ID Configuration'),
    '#key_type' => 'associative',
    '#default_value' => 'default',
    '#options' => array(
      'default' => t('Use Drupal Default'),
      'configured' => t('Use Configured'),
    ),
    '#description' => t("Configured Number will be in format yydxx which is 'yy' last two digits of current year, 'd' is department digit, x's are ordered numbers"),
  );
  $form['School_No']['school_administration_num_range'] = array(
    '#type' => 'textarea',
    '#title' => t('Department Digits'),
    '#size' => 1,
    '#default_value' => str_replace(' ', '', variable_get('school_administration_num_range')),
    '#description' => t("Divide enrolling students to groups by setting 'd' at student ID format e.g.<br/>"
      . "Grade 7 Girls => 1,2,3<br/>"
      . "Grade 7 Boys => 4,5,6<br/>"
      . "Other Girls => 7<br/>"
      . "Other Boys => 8<br/>"),
  );
  $form['School_No']['school_administration_std_id_len'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of available digits for each groups'),
    '#default_value' => variable_get('school_administration_std_id_len', 2),
    '#size' => 1,
    '#maxlength' => 1,
    '#description' => t("How many x's you want in configured student ID<br/>"
                      . "Default value is 2"),
  );
  $form['select_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Options'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['select_options']['school_administration_jobs'] = array(
    '#type' => 'textarea',
    '#title' => t('Jobs'),
    '#default_value' => variable_get('school_administration_jobs'),
    '#size' => 4,
  );
  $form['select_options']['school_administration_relations'] = array(
    '#type' => 'textarea',
    '#title' => t('Relations'),
    '#default_value' => variable_get('school_administration_relations'),
    '#size' => 4,
  );
  $form['select_options']['school_administration_withd'] = array(
    '#type' => 'textarea',
    '#title' => t('Withdraw Reasons'),
    '#default_value' => variable_get('school_administration_withd'),
    '#size' => 4,
  );
  return system_settings_form($form);
}

function school_administration_identity_information() {
  $form['identity'] = array(
    '#type' => 'fieldset',
    '#title' => t('Identity Information'),
    '#weight' => 0,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['identity']['NationalIdNo'] = array(
    '#type' => 'textfield',
    '#title' => t('National ID No'),
    '#weight' => 0,
    '#size' => 20,
  );
  $form['identity']['Name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name(s)'),
    '#weight' => 1,
    '#required' => TRUE,
  );
  $form['identity']['Surname'] = array(
    '#type' => 'textfield',
    '#title' => t('Surname'),
    '#weight' => 2,
    '#required' => TRUE,
  );
  $form['identity']['DOB'] = array(
    '#type' => 'date',
    '#title' => t('Date of birth'),
    '#weight' => 3,
    '#required' => TRUE,
    '#default_value' => array('day' => 01, 'month' => 01, 'year' => 1990),
  );
  $form['identity']['POB'] = array(
    '#type' => 'textfield',
    '#title' => t('Place of Birth'),
    '#weight' => 4,
    '#required' => TRUE,
    '#size' => 20,
  );
  $form['identity']['Nationality'] = array(
    '#type' => 'textfield',
    '#title' => t('Nationality'),
    '#weight' => 5,
    '#required' => TRUE,
    '#size' => 20,
  );
  $form['identity']['Gender'] = array(
    '#type' => 'radios',
    '#title' => t('Gender'),
    '#weight' => 6,
    '#required' => TRUE,
    '#key_type' => 'associative',
    '#options' => variable_get('school_administration_gender'),
  );
  $form['identity']['FatherN'] = array(
    '#type' => 'textfield',
    '#title' => t("Father's Name"),
    '#weight' => 7,
  );
  $form['identity']['MotherN'] = array(
    '#type' => 'textfield',
    '#title' => t("Mother's Name"),
    '#weight' => 8,
  );
  $form['identity']['Address'] = array(
    '#type' => 'textarea',
    '#title' => t('Home Address'),
    '#resizable' => FALSE,
    '#weight' => 9,
    '#cols' => 58,
    '#rows' => 4,
  );
  $form['identity']['Notes'] = array(
    '#type' => 'textarea',
    '#title' => t('Notes'),
    '#weight' => 10,
    '#resizable' => FALSE,
    '#cols' => 58,
    '#rows' => 2,
  );
  return $form;
}

function school_administration_work_info_form() {
  $form['job'] = array(
    '#type' => 'fieldset',
    '#title' => t("Job Information"),
    '#weight' => 10,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['job']['Occupation'] = array(
    '#type' => 'textfield',
    '#title' => t('Occupation'),
    '#required' => TRUE,
    '#weight' => 4,
  );
  $form['job']['Type'] = array(
    '#type' => 'radios',
    '#title' => t('Employment Type'),
    '#weight' => 5,
    '#key_type' => 'associative',
    '#options' => variable_get('school_administration_job_types'),
  );
  $form['job']['O/C/G-name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#weight' => 6,
  );
  $form['job']['O/C/G-details'] = array(
    '#type' => 'textfield',
    '#title' => t('Details'),
    '#weight' => 7,
  );
  $form['job']['Division'] = array(
    '#type' => 'textfield',
    '#title' => t('Division / Department'),
    '#weight' => 8,
  );
  $form['job']['Work_description'] = array(
    '#type' => 'textfield',
    '#title' => t('Work Description'),
    '#weight' => 9,
  );
  return $form;
}

function school_administration_contact_info_form() {
  $form['contact'] = array(
    '#type' => 'fieldset',
    '#title' => t("Contact Information"),
    '#weight' => 10,
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['contact']['tel'] = array(
    '#type' => 'textfield',
    '#title' => t('Tel'),
    '#weight' => 10,
    '#size' => 20,
  );
  $form['contact']['tel2'] = array(
    '#type' => 'textfield',
    '#title' => t('Second Tel'),
    '#weight' => 10,
    '#size' => 20,
  );
  $form['contact']['e-mail'] = array(
    '#type' => 'textfield',
    '#title' => t('e-mail'),
    '#weight' => 11,
    '#description' => t('This is needed to send username & password to make the person reach to school database system'),
  );
  return $form;
}